@@ -3,20 +3,20 @@ function (noflevels, input.combs) {
     if (!is.matrix(input.combs)) {
         if (!is.vector(input.combs)) {
             cat("\n")
-            stop("input.combs must be either a base 3 matrix or a vector of line numbers.\n\n",
+            stop("input.combs must be either an solution-space matrix or a vector of line numbers.\n\n",
                  call. = FALSE)
             }
         else {
             if (any(input.combs > prod(noflevels + 1))) {
                 cat("\n")
-                stop(paste("Some line numbers do not belong in the 3^k space for",
+                stop(paste("Some line numbers do not belong in the solution-space for",
                            length(noflevels), "causal conditions.\n\n"), call. = FALSE)
                 }
             input.combs <- getRow(noflevels + 1, input.combs)
             }
         }
     mbase <- rev(c(1, cumprod(rev(noflevels + 1))))[-1]
-    allcombn <- t(createMatrix(noflevels)[-1, ])
-    unique(as.vector(apply(input.combs, 1, function(x) (x*mbase) %*% allcombn + 1)))
+    allcombn <- t(createMatrix(rep(2, length(noflevels)))[-1, ])
+    sort(unique(as.vector(apply(input.combs, 1, function(x) (x*mbase) %*% allcombn + 1))))
     }
 
